@@ -77,7 +77,7 @@ class NullHandler(logging.Handler):
 logger = logging.getLogger('pandaemonium')
 logger.addHandler(NullHandler())
 
-version = 0, 5, 3
+version = 0, 5, 4
 
 STDIN = 0
 STDOUT = 1
@@ -143,7 +143,7 @@ class Daemon(object):
                                         # None means True unless started by init
                                         # or superserver
             working_directory='/',      # directory to change to
-            umask=0o027,                # allow group reads, and world nothing
+            umask=0o077,                # only allow the daemon access to its files
             prevent_core=True,          # don't write core files
             process_ids=None,           # uid, gid to switch to (None means ask
                                         # the os who is really running things
